# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudesl.endpoint import endpoint_data

class BatchInsertItemsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cloudesl', '2018-08-01', 'BatchInsertItems','cloudesl')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StoreId(self):
		return self.get_query_params().get('StoreId')

	def set_StoreId(self,StoreId):
		self.add_query_param('StoreId',StoreId)

	def get_ItemInfos(self):
		return self.get_body_params().get('ItemInfo')

	def set_ItemInfos(self, ItemInfos):
		for depth1 in range(len(ItemInfos)):
			if ItemInfos[depth1].get('MemberPrice') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.MemberPrice', ItemInfos[depth1].get('MemberPrice'))
			if ItemInfos[depth1].get('ActionPrice') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ActionPrice', ItemInfos[depth1].get('ActionPrice'))
			if ItemInfos[depth1].get('ProductionPlace') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ProductionPlace', ItemInfos[depth1].get('ProductionPlace'))
			if ItemInfos[depth1].get('BeSourceCode') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BeSourceCode', ItemInfos[depth1].get('BeSourceCode'))
			if ItemInfos[depth1].get('StoreId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.StoreId', ItemInfos[depth1].get('StoreId'))
			if ItemInfos[depth1].get('BrandName') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BrandName', ItemInfos[depth1].get('BrandName'))
			if ItemInfos[depth1].get('PromotionStart') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionStart', ItemInfos[depth1].get('PromotionStart'))
			if ItemInfos[depth1].get('SourceCode') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SourceCode', ItemInfos[depth1].get('SourceCode'))
			if ItemInfos[depth1].get('ItemId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemId', ItemInfos[depth1].get('ItemId'))
			if ItemInfos[depth1].get('ExtraAttribute') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ExtraAttribute', ItemInfos[depth1].get('ExtraAttribute'))
			if ItemInfos[depth1].get('CompanyId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CompanyId', ItemInfos[depth1].get('CompanyId'))
			if ItemInfos[depth1].get('PriceUnit') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PriceUnit', ItemInfos[depth1].get('PriceUnit'))
			if ItemInfos[depth1].get('Rank') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.Rank', ItemInfos[depth1].get('Rank'))
			if ItemInfos[depth1].get('ItemBarCode') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemBarCode', ItemInfos[depth1].get('ItemBarCode'))
			if ItemInfos[depth1].get('BePromotion') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BePromotion', ItemInfos[depth1].get('BePromotion'))
			if ItemInfos[depth1].get('PromotionEnd') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionEnd', ItemInfos[depth1].get('PromotionEnd'))
			if ItemInfos[depth1].get('ItemTitle') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemTitle', ItemInfos[depth1].get('ItemTitle'))
			if ItemInfos[depth1].get('OriginalPrice') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.OriginalPrice', ItemInfos[depth1].get('OriginalPrice'))
			if ItemInfos[depth1].get('ItemShortTitle') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemShortTitle', ItemInfos[depth1].get('ItemShortTitle'))
			if ItemInfos[depth1].get('CustomizeFeatureC') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureC', ItemInfos[depth1].get('CustomizeFeatureC'))
			if ItemInfos[depth1].get('ItemQrCode') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemQrCode', ItemInfos[depth1].get('ItemQrCode'))
			if ItemInfos[depth1].get('CustomizeFeatureD') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureD', ItemInfos[depth1].get('CustomizeFeatureD'))
			if ItemInfos[depth1].get('PromotionReason') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionReason', ItemInfos[depth1].get('PromotionReason'))
			if ItemInfos[depth1].get('CustomizeFeatureE') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureE', ItemInfos[depth1].get('CustomizeFeatureE'))
			if ItemInfos[depth1].get('CustomizeFeatureF') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureF', ItemInfos[depth1].get('CustomizeFeatureF'))
			if ItemInfos[depth1].get('ForestSecondId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ForestSecondId', ItemInfos[depth1].get('ForestSecondId'))
			if ItemInfos[depth1].get('CustomizeFeatureG') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureG', ItemInfos[depth1].get('CustomizeFeatureG'))
			if ItemInfos[depth1].get('CustomizeFeatureH') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureH', ItemInfos[depth1].get('CustomizeFeatureH'))
			if ItemInfos[depth1].get('CustomizeFeatureI') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureI', ItemInfos[depth1].get('CustomizeFeatureI'))
			if ItemInfos[depth1].get('CustomizeFeatureJ') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureJ', ItemInfos[depth1].get('CustomizeFeatureJ'))
			if ItemInfos[depth1].get('OptionGroups') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.OptionGroups', ItemInfos[depth1].get('OptionGroups'))
			if ItemInfos[depth1].get('ModelNumber') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ModelNumber', ItemInfos[depth1].get('ModelNumber'))
			if ItemInfos[depth1].get('SaleSpec') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SaleSpec', ItemInfos[depth1].get('SaleSpec'))
			if ItemInfos[depth1].get('CustomizeFeatureA') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureA', ItemInfos[depth1].get('CustomizeFeatureA'))
			if ItemInfos[depth1].get('CustomizeFeatureB') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureB', ItemInfos[depth1].get('CustomizeFeatureB'))
			if ItemInfos[depth1].get('SuggestPrice') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SuggestPrice', ItemInfos[depth1].get('SuggestPrice'))
			if ItemInfos[depth1].get('ForestFirstId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ForestFirstId', ItemInfos[depth1].get('ForestFirstId'))
			if ItemInfos[depth1].get('CategoryName') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CategoryName', ItemInfos[depth1].get('CategoryName'))
			if ItemInfos[depth1].get('EnergyEfficiency') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.EnergyEfficiency', ItemInfos[depth1].get('EnergyEfficiency'))
			if ItemInfos[depth1].get('SkuId') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SkuId', ItemInfos[depth1].get('SkuId'))
			if ItemInfos[depth1].get('PromotionText') is not None:
				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionText', ItemInfos[depth1].get('PromotionText'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudesl.endpoint import endpoint_data

class DescribeUserOperationLogRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cloudesl', '2018-08-01', 'DescribeUserOperationLog','cloudesl')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_OperateUserId(self):
		return self.get_query_params().get('OperateUserId')

	def set_OperateUserId(self,OperateUserId):
		self.add_query_param('OperateUserId',OperateUserId)

	def get_StoreId(self):
		return self.get_query_params().get('StoreId')

	def set_StoreId(self,StoreId):
		self.add_query_param('StoreId',StoreId)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_FromDate(self):
		return self.get_query_params().get('FromDate')

	def set_FromDate(self,FromDate):
		self.add_query_param('FromDate',FromDate)

	def get_ItemId(self):
		return self.get_query_params().get('ItemId')

	def set_ItemId(self,ItemId):
		self.add_query_param('ItemId',ItemId)

	def get_ToDate(self):
		return self.get_query_params().get('ToDate')

	def set_ToDate(self,ToDate):
		self.add_query_param('ToDate',ToDate)

	def get_EslBarCode(self):
		return self.get_query_params().get('EslBarCode')

	def set_EslBarCode(self,EslBarCode):
		self.add_query_param('EslBarCode',EslBarCode)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_ItemBarCode(self):
		return self.get_query_params().get('ItemBarCode')

	def set_ItemBarCode(self,ItemBarCode):
		self.add_query_param('ItemBarCode',ItemBarCode)

	def get_ItemTitle(self):
		return self.get_query_params().get('ItemTitle')

	def set_ItemTitle(self,ItemTitle):
		self.add_query_param('ItemTitle',ItemTitle)

	def get_OperateStatus(self):
		return self.get_query_params().get('OperateStatus')

	def set_OperateStatus(self,OperateStatus):
		self.add_query_param('OperateStatus',OperateStatus)

	def get_Reverse(self):
		return self.get_query_params().get('Reverse')

	def set_Reverse(self,Reverse):
		self.add_query_param('Reverse',Reverse)

	def get_OperateType(self):
		return self.get_query_params().get('OperateType')

	def set_OperateType(self,OperateType):
		self.add_query_param('OperateType',OperateType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudesl.endpoint import endpoint_data

class DescribeEslDevicesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cloudesl', '2018-08-01', 'DescribeEslDevices','cloudesl')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StoreId(self):
		return self.get_query_params().get('StoreId')

	def set_StoreId(self,StoreId):
		self.add_query_param('StoreId',StoreId)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

	def get_Mac(self):
		return self.get_query_params().get('Mac')

	def set_Mac(self,Mac):
		self.add_query_param('Mac',Mac)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_EslBarCode(self):
		return self.get_query_params().get('EslBarCode')

	def set_EslBarCode(self,EslBarCode):
		self.add_query_param('EslBarCode',EslBarCode)

	def get_Vendor(self):
		return self.get_query_params().get('Vendor')

	def set_Vendor(self,Vendor):
		self.add_query_param('Vendor',Vendor)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_ItemBarCode(self):
		return self.get_query_params().get('ItemBarCode')

	def set_ItemBarCode(self,ItemBarCode):
		self.add_query_param('ItemBarCode',ItemBarCode)

	def get_ToBatteryLevel(self):
		return self.get_query_params().get('ToBatteryLevel')

	def set_ToBatteryLevel(self,ToBatteryLevel):
		self.add_query_param('ToBatteryLevel',ToBatteryLevel)

	def get_FromBatteryLevel(self):
		return self.get_query_params().get('FromBatteryLevel')

	def set_FromBatteryLevel(self,FromBatteryLevel):
		self.add_query_param('FromBatteryLevel',FromBatteryLevel)

	def get_ShelfCode(self):
		return self.get_query_params().get('ShelfCode')

	def set_ShelfCode(self,ShelfCode):
		self.add_query_param('ShelfCode',ShelfCode)

	def get_BeBind(self):
		return self.get_query_params().get('BeBind')

	def set_BeBind(self,BeBind):
		self.add_query_param('BeBind',BeBind)


#!/usr/bin/python
'''
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
'''

from setuptools import setup, find_packages
import os
import sys

"""
setup module for cloudesl.

Created on 7/3/2015

@author: alex
"""

PACKAGE = "aliyunsdkcloudesl"
NAME = "aliyun-python-sdk-cloudesl"
DESCRIPTION = "The cloudesl module of Aliyun Python sdk."
AUTHOR = "Aliyun"
AUTHOR_EMAIL = "aliyun-developers-efficiency@list.alibaba-inc.com"
URL = "http://develop.aliyun.com/sdk/python"

TOPDIR = os.path.dirname(__file__) or "."
VERSION = __import__(PACKAGE).__version__

desc_file = open("README.rst")
try:
	LONG_DESCRIPTION = desc_file.read()
finally:
	desc_file.close()

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="Apache",
    url=URL,
    keywords=["aliyun","sdk","cloudesl"],
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    platforms="any",
    install_requires=["aliyun-python-sdk-core>=2.11.5",],
    classifiers=(
                "Development Status :: 4 - Beta",
                "Intended Audience :: Developers",
                "License :: OSI Approved :: Apache Software License",
                "Programming Language :: Python",
                "Programming Language :: Python :: 2.6",
                "Programming Language :: Python :: 2.7",
                "Programming Language :: Python :: 3",
                "Programming Language :: Python :: 3.3",
                "Programming Language :: Python :: 3.4",
                "Programming Language :: Python :: 3.5",
                "Programming Language :: Python :: 3.6",
                "Topic :: Software Development",
              )

)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudesl.endpoint import endpoint_data

class DescribeAlarmsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cloudesl', '2018-08-01', 'DescribeAlarms','cloudesl')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StoreId(self):
		return self.get_query_params().get('StoreId')

	def set_StoreId(self,StoreId):
		self.add_query_param('StoreId',StoreId)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_FromAlarmTime(self):
		return self.get_query_params().get('FromAlarmTime')

	def set_FromAlarmTime(self,FromAlarmTime):
		self.add_query_param('FromAlarmTime',FromAlarmTime)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_ToAlarmTime(self):
		return self.get_query_params().get('ToAlarmTime')

	def set_ToAlarmTime(self,ToAlarmTime):
		self.add_query_param('ToAlarmTime',ToAlarmTime)

	def get_AlarmType(self):
		return self.get_query_params().get('AlarmType')

	def set_AlarmType(self,AlarmType):
		self.add_query_param('AlarmType',AlarmType)

	def get_AlarmStatus(self):
		return self.get_query_params().get('AlarmStatus')

	def set_AlarmStatus(self,AlarmStatus):
		self.add_query_param('AlarmStatus',AlarmStatus)

	def get_ErrorType(self):
		return self.get_query_params().get('ErrorType')

	def set_ErrorType(self,ErrorType):
		self.add_query_param('ErrorType',ErrorType)

	def get_AlarmId(self):
		return self.get_query_params().get('AlarmId')

	def set_AlarmId(self,AlarmId):
		self.add_query_param('AlarmId',AlarmId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudesl.endpoint import endpoint_data

class CreateStoreRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cloudesl', '2018-08-01', 'CreateStore','cloudesl')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StoreName(self):
		return self.get_query_params().get('StoreName')

	def set_StoreName(self,StoreName):
		self.add_query_param('StoreName',StoreName)

	def get_ParentId(self):
		return self.get_query_params().get('ParentId')

	def set_ParentId(self,ParentId):
		self.add_query_param('ParentId',ParentId)

	def get_CompanyId(self):
		return self.get_query_params().get('CompanyId')

	def set_CompanyId(self,CompanyId):
		self.add_query_param('CompanyId',CompanyId)

	def get_Brand(self):
		return self.get_query_params().get('Brand')

	def set_Brand(self,Brand):
		self.add_query_param('Brand',Brand)

	def get_Comments(self):
		return self.get_query_params().get('Comments')

	def set_Comments(self,Comments):
		self.add_query_param('Comments',Comments)

	def get_Groups(self):
		return self.get_query_params().get('Groups')

	def set_Groups(self,Groups):
		self.add_query_param('Groups',Groups)

	def get_Phone(self):
		return self.get_query_params().get('Phone')

	def set_Phone(self,Phone):
		self.add_query_param('Phone',Phone)

	def get_OutId(self):
		return self.get_query_params().get('OutId')

	def set_OutId(self,OutId):
		self.add_query_param('OutId',OutId)